@@ -1,7 +1,7 @@
 /*********************************************************************
   Blosc - Blocked Shuffling and Compression Library
 
-  Copyright (c) 2021  The Blosc Development Team <blosc@blosc.org>
+  Copyright (c) 2021  Blosc Development Team <blosc@blosc.org>
   https://blosc.org
   License: BSD 3-Clause (see LICENSE.txt)
 
@@ -13,7 +13,7 @@
   @brief Blosc2 header file.
 
   This file contains Blosc2 public API and the structures needed to use it.
-  @author The Blosc Development Team <blosc@blosc.org>
+  @author Blosc Development Team <blosc@blosc.org>
 **********************************************************************/
 
 #ifndef BLOSC_BLOSC2_H
@@ -82,11 +82,11 @@ extern "C" {
 
 /* Version numbers */
 #define BLOSC2_VERSION_MAJOR    2    /* for major interface/format changes  */
-#define BLOSC2_VERSION_MINOR    13   /* for minor interface/format changes  */
-#define BLOSC2_VERSION_RELEASE  1    /* for tweaks, bug-fixes, or development */
+#define BLOSC2_VERSION_MINOR    14   /* for minor interface/format changes  */
+#define BLOSC2_VERSION_RELEASE  4    /* for tweaks, bug-fixes, or development */
 
-#define BLOSC2_VERSION_STRING   "2.13.1"  /* string version.  Sync with above! */
-#define BLOSC2_VERSION_DATE     "$Date:: 2023-01-25 #$"    /* date version */
+#define BLOSC2_VERSION_STRING   "2.14.4"  /* string version.  Sync with above! */
+#define BLOSC2_VERSION_DATE     "$Date:: 2023-04-10 #$"    /* date version */
 
 
 /* The maximum number of dimensions for Blosc2 NDim arrays */
@@ -245,14 +245,22 @@ enum {
  */
 enum {
 #ifndef BLOSC_H
-  BLOSC_NOSHUFFLE = 0,   //!< No shuffle (for compatibility with Blosc1).
-  BLOSC_NOFILTER = 0,    //!< No filter.
-  BLOSC_SHUFFLE = 1,     //!< Byte-wise shuffle.
-  BLOSC_BITSHUFFLE = 2,  //!< Bit-wise shuffle.
+  BLOSC_NOSHUFFLE = 0,
+  //!< No shuffle (for compatibility with Blosc1).
+  BLOSC_NOFILTER = 0,
+  //!< No filter.
+  BLOSC_SHUFFLE = 1,
+  //!< Byte-wise shuffle. `filters_meta` does not have any effect here.
+  BLOSC_BITSHUFFLE = 2,
+  //!< Bit-wise shuffle. `filters_meta` does not have any effect here.
 #endif // BLOSC_H
-  BLOSC_DELTA = 3,       //!< Delta filter.
-  BLOSC_TRUNC_PREC = 4,  //!< Truncate mantissa precision; positive values in cparams.filters_meta will keep bits; negative values will reduce bits.
-  BLOSC_LAST_FILTER = 5, //!< sentinel
+  BLOSC_DELTA = 3,
+  //!< Delta filter. `filters_meta` does not have any effect here.
+  BLOSC_TRUNC_PREC = 4,
+  //!< Truncate mantissa precision.
+  //!< Positive values in `filters_meta` will keep bits; negative values will zero bits.
+  BLOSC_LAST_FILTER = 5,
+  //!< sentinel
   BLOSC_LAST_REGISTERED_FILTER = BLOSC2_GLOBAL_REGISTERED_FILTERS_START + BLOSC2_GLOBAL_REGISTERED_FILTERS - 1,
   //!< Determine the last registered filter. It is used to check if a filter is registered or not.
 };
@@ -1929,7 +1937,7 @@ BLOSC_EXPORT int64_t blosc2_schunk_delete_chunk(blosc2_schunk *schunk, int64_t n
  * @return The number of chunks in super-chunk. If some problem is
  * detected, this number will be negative.
  */
-BLOSC_EXPORT int64_t blosc2_schunk_append_buffer(blosc2_schunk *schunk, void *src, int32_t nbytes);
+BLOSC_EXPORT int64_t blosc2_schunk_append_buffer(blosc2_schunk *schunk, const void *src, int32_t nbytes);
 
 /**
  * @brief Decompress and return the @p nchunk chunk of a super-chunk.
@@ -2083,7 +2091,7 @@ BLOSC_EXPORT int64_t blosc2_schunk_frame_len(blosc2_schunk* schunk);
  * If there is an error, a negative value is returned.
  */
 BLOSC_EXPORT int64_t blosc2_schunk_fill_special(blosc2_schunk* schunk, int64_t nitems,
-                                            int special_value, int32_t chunksize);
+                                                int special_value, int32_t chunksize);
 
 
 /*********************************************************************
@@ -2505,6 +2513,11 @@ BLOSC_EXPORT void blosc2_multidim_to_unidim(const int64_t *index, int8_t ndim, c
 BLOSC_EXPORT int blosc2_get_slice_nchunks(blosc2_schunk* schunk, int64_t *start, int64_t *stop, int64_t **chunks_idx);
 
 
+/*********************************************************************
+  Private functions, these are here for convenience,
+  and are not meant to be included in public docs
+*********************************************************************/
+
 // Private function needed in b2nd.h for deserializing meta
 static inline void swap_store(void *dest, const void *pa, int size) {
   uint8_t *pa_ = (uint8_t *) pa;
